香水 (豆瓣)
Description: 香水电影简介和剧情介绍,香水影评、图片、预告片、影讯、论坛、在线购票
Keywords: 香水,Perfume: The Story of a Murderer,香水影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.245豆瓣电影Top250

# 香水 Perfume: The Story of a Murderer (2006)

导演: 汤姆·提克威
编剧: 安德鲁·伯金 / 贝尔恩德·艾辛格 / 汤姆·提克威 / 帕特里克·聚斯金德
主演: 本·卫肖 / 艾伦·瑞克曼 / 蕾切儿·哈伍德 / 达斯汀·霍夫曼 / 大卫·卡尔德 / 比吉特·米尼希迈尔 / 卡洛斯·格拉马赫 / 西恩·托马斯 / 佩里·米尔沃德 / 山姆·道格拉斯 / 卡洛琳·赫弗斯 / 卡罗丽娜·维拉·斯克利亚 / 莎拉·弗里斯蒂 / 科琳娜·哈弗奇 / 杰西卡·施瓦茨 / 约翰·赫特 / 拉蒙·普霍尔
类型: 剧情 / 犯罪 / 奇幻
制片国家/地区: 德国 / 法国 / 西班牙 / 美国 / 比利时
语言: 英语
上映日期: 2006-09-07(德国) / 2006-09-14(法国) / 2006-11-24(西班牙) / 2007-01-05(美国)
片长: 147分钟
又名: 香水：一个杀人犯的故事 / 香水：一个谋杀犯的故事 / 香水：杀手的故事 / 杀手故事 / Das Parfum - Die Geschichte eines Mörders
IMDb: tt0396171
豆瓣评分
引用
8.5
523410人评价
5星
42.2%
4星
43.1%
3星
12.8%
2星
1.4%
1星
0.6%
好于 97% 犯罪片
好于 96% 剧情片
想看 看过
评价:
推荐

## 香水的剧情简介 · · · · · ·

十八世纪，让-马普蒂斯特•格雷诺耶（本•韦肖 Ben Whishaw 饰）出生在巴黎最肮脏、最恶臭不堪的地方——鱼市场上。格雷诺耶天生对气味有着惊人的天赋：无论恶臭还芳香，他都一一记住，并能轻易分辨各种气味。
当他在孤儿院长到13岁的时候，被院长卖给了制皮匠。格雷诺耶在制皮铺过着犬马不如的生活。机缘巧合，格雷诺耶在香水巴尔蒂尼面前展露了其过人的天赋，进入了香水铺工作。但格雷诺耶并不仅仅满足于制作出世界上最芳香的香水，他梦想学得如何保存万物气味的方法。巴尔蒂尼告诉格雷诺耶香水的起源地在格拉斯，那里的人知道保存气味的方法。格雷诺耶拿着巴尔蒂尼的推荐信来到了格拉斯。
格雷诺耶爱上了青春少女的体香，为了把这种香味保存下来，格雷诺耶最终走上了杀手的道路。 ©豆瓣

## 香水的演职员 · · · · · · ( 全部 34 )

- 汤姆·提克威 导演
- 本·卫肖 饰 让·巴蒂斯特·格雷诺耶 Jean-Baptiste Grenouille
- 艾伦·瑞克曼 饰 瑞奇斯 Richis
- 蕾切儿·哈伍德 饰 劳拉 Laura
- 达斯汀·霍夫曼 饰 朱塞佩·巴尔蒂尼 Giuseppe Baldini
- 大卫·卡尔德 饰 格拉斯主教 Bishop of Grasse

## 香水的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片1553 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  沉默的羔羊

  猫鼠游戏

  七宗罪

  致命ID

  恐怖游轮

  闪灵

  杀人回忆

  黑天鹅

  孤儿怨

  电锯惊魂

我要写短评

## 香水的短评 · · · · · · ( 全部 115675 条 )

热门 / 最新 / 好友

### 3746 有用 正统文化代言人 看过 2007-10-07 20:16:23

一个单凭体香达到高潮的男人

### 7554 有用 皮皮鲁西西 看过 2010-04-26 22:03:12

这简直就是一部资本主义发展史，出生于最肮脏和腐臭的地方，却追求最纯粹的美，通过杀戮得到迷惑人心的力量，就连最痛恨他的人也甘愿俯首称臣，最后犹如寓言一般消失于这个世界......

### 1847 有用 苏格 看过 2009-07-31 21:34:46

最大的缺点是：我根本闻不到香水嘛，你在那陶醉个啥？

### 2009 有用 SilentTyler 看过 2010-01-03 14:19:29

观影过程中如果曾有过那么一丝丝对杀手的憎恶, 那么你便是世俗和不纯洁的.

### 2173 有用 眠去 看过 2007-02-22 11:06:21

有人曾告诉我他不顾一切寻找的其实是爱情的味道，爱情也有香吗？他试图拥有世上最奇异圣洁的香水，当世人在广场狂欢，以达爱与欲的颠峰，他却在最后发现他已失去爱人的能力。没有爱情，香味消失了。他仿佛从未存在过。

> 更多短评 115675条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 香水的影评 · · · · · · ( 全部 2811 条 )

热门 / 最新 / 好友
魔派 2007-01-22 09:44:27

## 香水：提克威的阅读理解错误

在原著中，作者徐四金（Patrick Suskind）一开始就借泰利耶神甫这一角色略带鄙夷表示，嗅觉是所有感觉里面最不高贵的，人类对于味道的语言形容贫乏得不成比例，而人类的味道一直是肉体的，因此总是罪恶的味道。如果按照达尔文进化论原理，这似乎有所道理。人类的嗅觉在离开远古... (展开)
5066 331 397回应 收起
刘放 2007-04-17 10:53:49

## 文字的力量

在我迄今为止的读书生涯中，有两本书绝对重要。 一本是加西亚·马尔克斯的《百年孤独》，一本是帕·聚斯金德的《香水》。 前一本书直接导致我在相当长一段时间内热衷于东编西抄地弄一些小故事出来，证据就是，那些小故事常常以“很多年之后当我回想往事就怎么怎么”或者“后来... (展开)
1273 260 187回应 收起
≈猫鬼空≈ 2006-10-31 03:21:49

## 出于爱（par amour）【看第二遍，发现理解有错】

看第二遍，发现理解错很多……语言啊…… 　　 　　 　　离弃他的，必然要被生命遗弃 　　他本没有错，却被爱遗弃一生 　　 　　电影正片的开场，伴着画外音，镜头摇晃似乎走路的人的视线－－1744年，法国。肮脏杂乱的菜市场；一个男人将一筐鱼倒下，和一个同样浑身腥臭... (展开)
735 325 241回应 收起
刘媛 2006-10-29 12:38:13

## 寻香

巴黎的十月，各种气息浑圆丰满，仿佛它们的快乐就在于被人发现、被人采集。当地上湿嗒嗒的积满了水，刚落下叶子被泡出一股将腐未腐的甜蜜。我去看《香水》（Profumo-una storia di un'assassino） 　　 影片开场是巴黎街市的景象，十八世纪的香都弥漫着难以想象的恶臭。巴蒂斯... (展开)
354 107 133回应 收起
郭大路 2010-06-26 12:29:23

## 卑劣的人生，可憎的人格！

看完这部电影再到这里来看评论。出乎意料的居然没看到什么差评，继而又看到： 假如理解为对自己艺术理想的执着与偏执的话，真的很棒/观影过程中如果曾有过那么一丝丝对杀手的憎恶, 那么你便是不纯洁的/不愧是我最爱的导演，故事如此酣畅淋漓，一个如此美妙的杀手故事，非常... (展开)
367 205 159回应 收起
魔幽幽游猫猫 2012-05-26 22:20:37

## 一部为仇女屌丝洗白的男权丧失片

这篇影评可能有剧透

我觉得此片就纯粹是一部给仇女吊丝洗白的片子，但是豆瓣影评下面还有很多跟风的装X者 说不喜欢此片就是“智商不够，艺术修养也还没到一个层次而已” 艹，男人杀死活生生的女人做成所谓的艺术品就叫艺术吗？那如果是一部女吊丝杀优秀男人做成死物的片子，各位觉得舆论还会这么... (展开)
617 432 312回应 收起
被迫改名 2008-04-20 21:48:49

## 传奇的背后：看《香水》的电影

德国导演汤姆·提克威（Tom Tykwer）之为我们所熟悉，多半因为《疾走罗拉》。他的导演作品中充分展现了活力、叙事能力以及对基耶斯洛夫斯基的敬意。所以他导演《香水》值得我们的期待。 《香水》首先是一部关于气味的小说，是香味的百科全书。它的故事富有传奇色彩。电影在叙... (展开)
179 31 68回应 收起
于是 2006-11-03 23:49:10

## 完美的视觉

我所迷恋的是电影中Goya油画般的光影和轮廓。适合脏乱的丰富感，极端的贫穷和极端的奢华。 用电影语言去表现嗅觉，这本来就是很让人屏息凝神的。我很感激演员们的表演。无论是做香水的、还是被害的女人。 在故事后半段，隐秘的行为渐渐疯狂，越来越多的女人被杀害，抛尸的现场... (展开)
164 27 31回应 收起
叶飞Phoenix 2009-08-04 21:18:08

## 生命的绚丽绽放，奇异与主流的对抗——解读《香水》

----前调---- 十八世纪的法国，曾出现过一位最有天赋和最残暴的人物 他的名字早已被人们遗忘 “因为他的天才和他的野心仅仅局限在历史上没有留下痕迹的领域——气味的短暂王国” “在我们所说的那个时代，各个城市里始终弥漫着我们现代人难以想象的臭气。……” 就在那个盛... (展开)
183 18 28回应 收起

> 更多影评 2811篇

添加新讨论

## 讨论区 · · · · · ·

为什么一直破不了案？ | 来自一个热心网友 | 5 回应 | 2022-11-19 03:33:22
知道电影想表达什么，但就是看不惯 | 来自进击的学渣 | 77 回应 | 2022-11-08 16:29:47
想看想看完整的哪里可以看啊 | 来自硕自帅 | 13 回应 | 2022-11-04 20:17:30
有人觉得达斯汀霍夫曼在片子里很像沈腾吗 | 来自Omnívoro | 2 回应 | 2022-11-04 00:59:31
这想法真恐怖、恶心“ 观影过程中如果曾有过那么一... | 来自白狼王 | 32 回应 | 2022-10-31 22:24:45

> 去这部影片的讨论区（全部500条）

## 关于《香水》的问题 · · · · · · ( 全部57个 )

- 为啥他要回到出生的地方被一群野蛮的人吃掉？ 35人回答
- 为什么格雷诺耶每次杀完人都把尸体送回原处？ 11人回答

> 全部57个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 【意外结局】 (影志)
- 关于德国 你该看的 (≌菩提风花)
- 意外结局+高智商 (鸟人与鱼)
- 【孤独的人】 (影志)

## 谁在看这部电影 · · · · · ·

- 大橘大利🍊
  1分钟前 想看
- 杨坚强
  5分钟前 看过
- 有才的二哈
  7分钟前 看过

752218人看过 / 266547人想看

订阅香水的评论:
feed: rss 2.0